# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [1.0.0-1] - 2024-12-06

### Changed

- No changes in code. Just bump package version to publish it on PyPI due to accidentally deleted `1.0.0` release.

## [1.0.0] - 2024-12-06

### Added

- 1st version of dummy decorator.

[1.0.0-1]: https://github.com/alexstaf/dummy-decorator/releases/tag/1.0.0-1
[1.0.0]: https://github.com/alexstaf/dummy-decorator/releases/tag/1.0.0
